function [BasisMZ,BasisIntensity, PeptideIndex] = GenerateBasis(PeptideInfo,PeptideMass, PeptideIntensity, RawFileDir, RawFileDirList, RawFileIndex)
% Input
% PeptideInfo:              The charge state, scan of ms/ms spectrum to identify the peptide, etc
% PeptideMass:              The theoretic isotopic mass values for each peptide
% PeptideIntensity:         The theoretic isotopic intensities for each peptide
% RawFileDir:               The directory for the decoded MS spectra
% RawFileDirList:           MS spectra file list
% RawFileIndex:             The index of the MS spectrum that need to build the model with
% Output
% BasisMZ:                  Match each mz value to the nearest identified peak
% BasisIntensity:           The theoretic isotopic intensities for bases
% PeptideIndex:             The index of the reference code for each peptide

peptide_info = PeptideInfo;

sel_ms_ms_content = peptide_info(:, 1);
analyze_raw_file_index = find(RawFileDirList == RawFileIndex);
begin_analyze_index = max(1, analyze_raw_file_index - 25);
end_analyze_index = min(length(RawFileDirList), analyze_raw_file_index + 25);
sel_index = find(sel_ms_ms_content > RawFileDirList(begin_analyze_index) & sel_ms_ms_content < RawFileDirList(end_analyze_index));

if isempty(sel_index) == 1
   BasisMZ = [];
   BasisIntensity=[];
   PeptideIndex =[];
   return;
end

refer_peptide_index = sel_index;
refer_peak_mz = PeptideMass(:,sel_index);
refer_peak_intensity = PeptideIntensity(:,sel_index);

raw_file_content = load([RawFileDir, num2str(RawFileIndex), '.txt']);
% Generate basis
for row_index=1:length(sel_index)
   refer_mz = refer_peak_mz(:, row_index);
   refer_peak_mz(:, row_index) = MatchPeak(refer_mz, raw_file_content);
end

BasisMZ = refer_peak_mz;
BasisIntensity = refer_peak_intensity;
PeptideIndex = refer_peptide_index;

zeros_index = (sum(BasisMZ) == 0);
BasisMZ(:,zeros_index) = [];
BasisIntensity(:,zeros_index) =[];
PeptideIndex(zeros_index)=[];
return;

function ResultMZ = MatchPeak(ReferMZ,RawFileContent)
ResultMZ = ReferMZ;
mass_diff = ReferMZ(2) - ReferMZ(1);

raw_file_mz = RawFileContent(:,1);
raw_file_intensity = RawFileContent(:,2);
peak_matched = zeros(3,1);
for analyze_index=1:3
    sel_list = find(raw_file_mz>=(ReferMZ(analyze_index)-0.6*mass_diff) & raw_file_mz <= (ReferMZ(analyze_index) + 0.6 * mass_diff));
    sel_intensity = raw_file_intensity(sel_list);
    if isempty(sel_intensity) == 1
       continue; 
    end
    max_index = find(sel_intensity == max(sel_intensity));
    if length(max_index) >= 2
        tmp_mz_list = [];
        for max_list_index = max_index'
            tmp_mz_list = [tmp_mz_list; raw_file_mz(sel_list(max_list_index))];
        end
        abs_diff = abs(tmp_mz_list - ReferMZ(analyze_index));
        max_index = max_index(abs_diff == min(abs_diff));
    end
    if max_index ~= length(sel_intensity) && max_index ~= 1
        ResultMZ(analyze_index) = raw_file_mz(sel_list(max_index));
        peak_matched(analyze_index) = 1;
    else
        if length(sel_intensity) == 1
            ResultMZ(analyze_index) = raw_file_mz(sel_list(max_index));
            peak_matched(analyze_index) = 1;
        end
    end
end
if sum(peak_matched(1:2)) == 0
    ResultMZ = zeros(3,1);
end
return;